@@ -1,6 +1,8 @@
+use std::time::Duration;
+
 use serde::{Serialize, Deserialize};
 
-use crate::client::Client;
+use crate::{client::Client, error::Error};
 
 #[derive(Debug, Serialize, Deserialize)]
 pub struct Account {
@@ -99,7 +101,7 @@ pub struct CheckResp {
 #[derive(Debug, Serialize, Deserialize)]
 pub struct Kick {
     #[serde(rename = "Identifier")]
-    identifier: String
+    identifier: String  
 }
 
 impl From<String> for Kick {
@@ -157,7 +159,7 @@ pub struct QueryResp {
 }
 
 pub struct AccountApi<'a> {
-    pub inner: &'a Client
+    inner: &'a Client
 }
 
 impl<'a> AccountApi<'a> {
@@ -167,4 +169,17 @@ impl<'a> AccountApi<'a> {
     define_api!(check, "v4/im_open_login_svc/account_check", CheckUsers, CheckResp);
     define_api!(kick, "v4/im_open_login_svc/kick", Kick, ());
     define_api!(query_online_status, "v4/openim/query_online_status", OnlineStatus, QueryResp);
+
+    pub fn gen_sign(&self, user_id: &str, expire: Duration) -> Result<String, Error> {
+        super::usersig::gen_usersig(
+            self.inner.sdkappid, 
+            self.inner.key.as_str(),
+            user_id, 
+            expire
+        )
+    }
+
+    pub fn new(client: &'a Client) -> Self {
+        AccountApi{inner: client}
+    }
 }
\ No newline at end of file
