@@ -23,7 +23,7 @@ pub struct BatchSendResp {
 }
 
 pub struct MessageApi<'a> {
-    pub inner: &'a Client
+    inner: &'a Client
 }
 
 impl<'a> MessageApi<'a> {
@@ -38,4 +38,8 @@ impl<'a> MessageApi<'a> {
     define_api!(mark_read, "v4/openim/admin_set_msg_read", BatchMessage, BatchSendResp);
     // 未读计数
     define_api!(unread_count, "v4/openim/get_c2c_unread_msg_num", BatchMessage, BatchSendResp);
+
+    pub fn new(client: &'a Client) -> Self {
+        Self {inner: client}
+    }
 }
\ No newline at end of file
