@@ -13,7 +13,8 @@ use crate::{
 
 #[derive(Clone)]
 pub struct Client {
-    sdkappid: u64,
+    pub sdkappid: u64,
+    pub key: String,
     identifier: String,
     http_client: reqwest::Client,
     sign: Arc<Mutex<String>>
@@ -37,10 +38,11 @@ impl Client {
 
         let sign_clone = sign.clone();
         let identifier_clone = identifier.clone();
-        tokio::spawn(Self::sign_gen_task(sign_clone, sdkappid, key, identifier_clone));
+        tokio::spawn(Self::sign_gen_task(sign_clone, sdkappid, key.clone(), identifier_clone));
 
         Client {
             sdkappid,
+            key,
             identifier,
             http_client,
             sign
