@@ -16,10 +16,10 @@ impl Client {
     }
 
     pub fn account(&self) -> AccountApi {
-        AccountApi {inner: &self.client}
+        AccountApi::new(&self.client)
     }
 
     pub fn message(&self) -> MessageApi {
-        MessageApi {inner: &self.client}
+        MessageApi::new(&self.client)
     }
 }
